pub fn return_create<CTX: ContextTr>(
context: &mut CTX,
checkpoint: JournalCheckpoint,
interpreter_result: &mut InterpreterResult,
address: Address,
)Expand description
Handles the result of a CREATE operation, including validation and state updates.
The EIP-8037 upfront CREATE state gas is charged on the parent’s tracker by
the CREATE/CREATE2 opcode. On child failure (revert/halt/early-fail) it is
refunded to the parent in return_result. The child frame is NOT allowed to
borrow the upfront charge to pay for code deposit: it must cover code deposit
state gas from its own reservoir and remaining gas.